summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorMonzero Build System <builds@monzero.org>2026-08-15 21:26:40 +0100
committerMonzero Build System <builds@monzero.org>2026-08-15 21:26:40 +0100
commitdceeb88444ce966caa1a133d2926d5f7213c87ff (patch)
treed74c9c7d7e43c2a0d39d656c690c63050cff7f53 /src
parent81f33c7e00bf183823909a02e6d96ce11e41adce (diff)
downloadmonzero-gui-phase0-20260815.tar.gz
monzero-gui-phase0-20260815.tar.xz
monzero-gui-phase0-20260815.zip
Establish Monzero GUI Phase 0 baselinemonzero-gui-phase0-20260815
Diffstat (limited to 'src')
-rw-r--r--src/CMakeLists.txt30
-rw-r--r--src/daemon/DaemonManager.cpp22
-rw-r--r--src/main/Logger.cpp8
-rw-r--r--src/main/main.cpp10
-rw-r--r--src/qt/TailsOS.cpp6
-rw-r--r--src/qt/utils.cpp14
6 files changed, 46 insertions, 44 deletions
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index b5718df3..81ee3c41 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -72,26 +72,26 @@ set(monero_wallet_gui_sources
)
if(NOT ANDROID)
- add_executable(monero-wallet-gui ${EXECUTABLE_FLAG} ${monero_wallet_gui_sources})
+ add_executable(monzero-wallet-gui ${EXECUTABLE_FLAG} ${monero_wallet_gui_sources})
else()
- add_library(monero-wallet-gui SHARED ${monero_wallet_gui_sources})
- set_target_properties(monero-wallet-gui PROPERTIES COMPILE_DEFINITIONS "ANDROID")
+ add_library(monzero-wallet-gui SHARED ${monero_wallet_gui_sources})
+ set_target_properties(monzero-wallet-gui PROPERTIES COMPILE_DEFINITIONS "ANDROID")
endif()
-set_target_properties(monero-wallet-gui PROPERTIES
+set_target_properties(monzero-wallet-gui PROPERTIES
RUNTIME_OUTPUT_DIRECTORY "${CMAKE_BINARY_DIR}/bin"
MACOSX_BUNDLE TRUE
MACOSX_BUNDLE_INFO_PLIST "${CMAKE_SOURCE_DIR}/share/Info.plist"
)
# OpenGL
-target_include_directories(monero-wallet-gui PUBLIC ${OPENGL_INCLUDE_DIR})
+target_include_directories(monzero-wallet-gui PUBLIC ${OPENGL_INCLUDE_DIR})
message(STATUS "OpenGL: include dir at ${OPENGL_INCLUDE_DIR}")
message(STATUS "OpenGL: libraries at ${OPENGL_LIBRARIES}")
-target_include_directories(monero-wallet-gui PUBLIC ${Qt5Gui_PRIVATE_INCLUDE_DIRS})
+target_include_directories(monzero-wallet-gui PUBLIC ${Qt5Gui_PRIVATE_INCLUDE_DIRS})
-target_include_directories(monero-wallet-gui PUBLIC
+target_include_directories(monzero-wallet-gui PUBLIC
${CMAKE_SOURCE_DIR}/monero/include
${CMAKE_SOURCE_DIR}/monero/src
${CMAKE_SOURCE_DIR}/monero/external/easylogging++
@@ -107,7 +107,7 @@ target_include_directories(monero-wallet-gui PUBLIC
${X11_INCLUDE_DIR}
)
-target_compile_definitions(monero-wallet-gui
+target_compile_definitions(monzero-wallet-gui
PUBLIC
${Qt5Widgets_DEFINITIONS}
${Qt5Qml_DEFINITIONS}
@@ -118,12 +118,12 @@ if(APPLE)
execute_process(COMMAND brew --prefix icu4c OUTPUT_VARIABLE ICU_ROOT OUTPUT_STRIP_TRAILING_WHITESPACE)
endif()
find_package(ICU REQUIRED COMPONENTS data i18n uc)
- target_link_directories(monero-wallet-gui PRIVATE ${ICU_ROOT}/lib)
+ target_link_directories(monzero-wallet-gui PRIVATE ${ICU_ROOT}/lib)
endif()
set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} ${Qt5Widgets_EXECUTABLE_COMPILE_FLAGS}")
-target_link_libraries(monero-wallet-gui
+target_link_libraries(monzero-wallet-gui
epee
common
net
@@ -139,13 +139,13 @@ target_link_libraries(monero-wallet-gui
)
if(X11_FOUND)
- target_link_libraries(monero-wallet-gui ${X11_LIBRARIES})
+ target_link_libraries(monzero-wallet-gui ${X11_LIBRARIES})
endif()
if(WITH_SCANNER)
- target_link_libraries(monero-wallet-gui qrscanner)
+ target_link_libraries(monzero-wallet-gui qrscanner)
if(LINUX AND NOT ANDROID)
- target_link_libraries(monero-wallet-gui
+ target_link_libraries(monzero-wallet-gui
jpeg
v4l2
v4lconvert
@@ -154,10 +154,10 @@ if(WITH_SCANNER)
endif()
endif()
-add_custom_command(TARGET monero-wallet-gui POST_BUILD COMMAND ${CMAKE_COMMAND} -E copy $<TARGET_FILE:daemon> $<TARGET_FILE_DIR:monero-wallet-gui>)
+add_custom_command(TARGET monzero-wallet-gui POST_BUILD COMMAND ${CMAKE_COMMAND} -E copy $<TARGET_FILE:daemon> $<TARGET_FILE_DIR:monzero-wallet-gui>)
include(Deploy)
-install(TARGETS monero-wallet-gui
+install(TARGETS monzero-wallet-gui
DESTINATION bin
)
diff --git a/src/main/Logger.cpp b/src/main/Logger.cpp
index 8fa98979..56091f42 100644
--- a/src/main/Logger.cpp
+++ b/src/main/Logger.cpp
@@ -42,15 +42,15 @@
#include "qt/TailsOS.h"
// default log path by OS (should be writable)
-static const QString defaultLogName = "monero-wallet-gui.log";
+static const QString defaultLogName = "monzero-wallet-gui.log";
#if defined(Q_OS_IOS)
//AppDataLocation = "<APPROOT>/Library/Application Support"
static const QString osPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).at(0);
- static const QString appFolder = "monero-wallet-gui";
+ static const QString appFolder = "monzero-wallet-gui";
#elif defined(Q_OS_WIN)
//AppDataLocation = "C:/Users/<USER>/AppData/Roaming/<APPNAME>"
static const QString osPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).at(0);
- static const QString appFolder = "monero-wallet-gui";
+ static const QString appFolder = "monzero-wallet-gui";
#elif defined(Q_OS_ANDROID)
//AppDataLocation = "<USER>/<APPNAME>/files"
static const QString osPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).at(1);
@@ -123,7 +123,7 @@ Logger::Logger(QCoreApplication &parent, QString userDefinedLogFilePath)
void Logger::resetLogFilePath(bool portable)
{
m_logFilePath = QDir::toNativeSeparators(getLogPath(m_userDefinedLogFilePath, portable));
- Monero::Wallet::init(m_applicationFilePath.c_str(), "monero-wallet-gui", m_logFilePath.toStdString(), true);
+ Monero::Wallet::init(m_applicationFilePath.c_str(), "monzero-wallet-gui", m_logFilePath.toStdString(), true);
qWarning() << "Logging to" << m_logFilePath;
emit logFilePathChanged();
}
diff --git a/src/main/main.cpp b/src/main/main.cpp
index cad6dded..23bc1c46 100644
--- a/src/main/main.cpp
+++ b/src/main/main.cpp
@@ -229,10 +229,10 @@ int main(int argc, char *argv[])
}
#endif
- app.setApplicationName("monero-core");
+ app.setApplicationName("monzero-core");
app.setDesktopFileName("org.getmonero.Monero");
- app.setOrganizationDomain("getmonero.org");
- app.setOrganizationName("monero-project");
+ app.setOrganizationDomain("monzero.org");
+ app.setOrganizationName("monzero-project");
// Ask to enable Tails OS persistence mode, it affects:
// - Log file location
@@ -385,7 +385,7 @@ Verify update binary using 'shasum'-compatible (SHA256 algo) output signed by tw
qmlRegisterType<WalletManager>("moneroComponents.WalletManager", 1, 0, "WalletManager");
// Temporary Qt.labs.settings replacement
- qmlRegisterType<MoneroSettings>("moneroComponents.Settings", 1, 0, "MoneroSettings");
+ qmlRegisterType<MoneroSettings>("moneroComponents.Settings", 1, 0, "MonzeroSettings");
qmlRegisterUncreatableType<Wallet>("moneroComponents.Wallet", 1, 0, "Wallet", "Wallet can't be instantiated directly");
@@ -504,7 +504,7 @@ Verify update binary using 'shasum'-compatible (SHA256 algo) output signed by tw
if (accountName.isEmpty())
accountName = qgetenv("USERNAME"); // Windows
if (accountName.isEmpty())
- accountName = "My monero Account";
+ accountName = "My Monzero Account";
engine.rootContext()->setContextProperty("defaultAccountName", accountName);
engine.rootContext()->setContextProperty("homePath", QDir::homePath());
diff --git a/src/qt/TailsOS.cpp b/src/qt/TailsOS.cpp
index 1ab15721..099dc39d 100644
--- a/src/qt/TailsOS.cpp
+++ b/src/qt/TailsOS.cpp
@@ -42,9 +42,9 @@ void TailsOS::showDataPersistenceDisabledWarning()
msgBox.setText(QObject::tr("Warning: persistence disabled"));
msgBox.setWindowTitle(QObject::tr("Warning: persistence disabled"));
msgBox.setInformativeText(
- QObject::tr("Monero GUI has detected that Tails persistence is "
+ QObject::tr("Monzero GUI has detected that Tails persistence is "
"currently disabled. Any configurations you make inside "
- "the Monero GUI will not be saved."
+ "the Monzero GUI will not be saved."
"\n\n"
"In addition, make sure to not save your wallet on the "
"filesystem, as it will be lost at shutdown."
@@ -62,7 +62,7 @@ void TailsOS::showDataPersistenceDisabledWarning()
void TailsOS::askPersistence()
{
QMessageBox msgBox;
- msgBox.setWindowTitle(QObject::tr("Monero GUI"));
+ msgBox.setWindowTitle(QObject::tr("Monzero GUI"));
msgBox.setText(QObject::tr("Use Tails persistence?"));
msgBox.setInformativeText(
QObject::tr("Persist wallet files and configuration on the encrypted volume?"
diff --git a/src/qt/utils.cpp b/src/qt/utils.cpp
index c5910d66..eba3affa 100644
--- a/src/qt/utils.cpp
+++ b/src/qt/utils.cpp
@@ -85,7 +85,7 @@ QString getAccountName(){
if (accountName.isEmpty())
accountName = qgetenv("USERNAME"); // Windows
if (accountName.isEmpty())
- accountName = "My monero Account";
+ accountName = "My Monzero Account";
return accountName;
}
@@ -93,11 +93,11 @@ QString getAccountName(){
QString xdgMime(){
return QString(
"[Desktop Entry]\n"
- "Name=Monero GUI\n"
- "GenericName=Monero-GUI\n"
- "X-GNOME-FullName=Monero-GUI\n"
- "Comment=Monero GUI\n"
- "Keywords=Monero;\n"
+ "Name=Monzero GUI\n"
+ "GenericName=Monzero GUI\n"
+ "X-GNOME-FullName=Monzero GUI\n"
+ "Comment=Monzero GUI\n"
+ "Keywords=Monzero;XMZ;\n"
"Exec=\"%1\" %u\n"
"Terminal=false\n"
"Type=Application\n"
@@ -107,7 +107,7 @@ QString xdgMime(){
"StartupNotify=true\n"
"X-GNOME-Bugzilla-Bugzilla=GNOME\n"
"X-GNOME-UsesNotifications=true\n"
- "StartupWMClass=monero-wallet-gui\n"
+ "StartupWMClass=monzero-wallet-gui\n"
).arg(QCoreApplication::applicationFilePath());
}
diff --git a/src/daemon/DaemonManager.cpp b/src/daemon/DaemonManager.cpp
index 60feebc7..67a75162 100644
--- a/src/daemon/DaemonManager.cpp
+++ b/src/daemon/DaemonManager.cpp
@@ -56,7 +56,7 @@ bool DaemonManager::start(const QString &flags, NetworkType::Type nettype, const
return false;
}
// prepare command line arguments and pass to monerod
QStringList arguments;
// Start daemon with --detach flag on non-windows platforms
@@ -68,6 +68,8 @@ bool DaemonManager::start(const QString &flags, NetworkType::Type nettype, const
arguments << "--testnet";
else if (nettype == NetworkType::STAGENET)
arguments << "--stagenet";
+ else if (!flags.contains("--add-priority-node", Qt::CaseSensitive))
+ arguments << "--add-priority-node" << "82.165.112.237:6174";
// Custom startup flags for daemon
foreach (const QString &str, flags.split(" ")) {
@@ -106,7 +108,7 @@ bool DaemonManager::start(const QString &flags, NetworkType::Type nettype, const
arguments << "--max-concurrency" << QString::number(concurrency);
}
- qDebug() << "starting monerod " + m_monerod;
+ qDebug() << "starting monzerod " + m_monerod;
qDebug() << "With command line arguments " << arguments;
QMutexLocker locker(&m_daemonMutex);
@@ -117,7 +119,7 @@ bool DaemonManager::start(const QString &flags, NetworkType::Type nettype, const
connect(m_daemon.get(), SIGNAL(readyReadStandardOutput()), this, SLOT(printOutput()));
connect(m_daemon.get(), SIGNAL(readyReadStandardError()), this, SLOT(printError()));
- // Start monerod
+ // Start monzerod
bool started = m_daemon->startDetached(m_monerod, arguments);
// add state changed listener
@@ -187,9 +189,9 @@ bool DaemonManager::stopWatcher(NetworkType::Type nettype, const QString &dataDi
if(counter >= 5) {
qDebug() << "Killing it! ";
#ifdef Q_OS_WIN
- QProcess::execute("taskkill", {"/F", "/IM", "monerod.exe"});
+ QProcess::execute("taskkill", {"/F", "/IM", "monzerod.exe"});
#else
- QProcess::execute("pkill", {"monerod"});
+ QProcess::execute("pkill", {"monzerod"});
#endif
}
@@ -349,7 +351,7 @@ QString DaemonManager::getArgs(const QString &dataDir) {
QStringList tempArgs;
#ifdef Q_OS_WIN
//powershell
- tempArgs << "Get-CimInstance Win32_Process -Filter \"name = 'monerod.exe'\" | select -ExpandProperty CommandLine ";
+ tempArgs << "Get-CimInstance Win32_Process -Filter \"name = 'monzerod.exe'\" | select -ExpandProperty CommandLine ";
p.setProgram("powershell");
p.setArguments(tempArgs);
p.start();
@@ -358,7 +360,7 @@ QString DaemonManager::getArgs(const QString &dataDir) {
#elif defined(Q_OS_UNIX)
//pgrep
- tempArgs << "monerod";
+ tempArgs << "monzerod";
p.setProgram("pgrep");
p.setArguments(tempArgs);
p.start();
@@ -397,11 +399,11 @@ DaemonManager::DaemonManager(QObject *parent)
, m_scheduler(this)
{
- // Platform depetent path to monerod
+ // Platform dependent path to the Monzero daemon.
#ifdef Q_OS_WIN
- m_monerod = QApplication::applicationDirPath() + "/monerod.exe";
+ m_monerod = QApplication::applicationDirPath() + "/monzerod.exe";
#elif defined(Q_OS_UNIX)
- m_monerod = QApplication::applicationDirPath() + "/monerod";
+ m_monerod = QApplication::applicationDirPath() + "/monzerod";
#endif
if (m_monerod.length() == 0) {
@@ -56,7 +56,7 @@ bool DaemonManager::start(const QString &flags, NetworkType::Type nettype, const
return false;
}
- // prepare command line arguments and pass to monerod
+ // prepare command line arguments and pass to monzerod
QStringList arguments;
// Start daemon with --detach flag on non-windows platforms